@@ -1,6 +1,6 @@
 /**
  *
- * $Id: Xm.h.in,v 1.15 1999/01/06 15:16:39 jon Exp $
+ * $Id: Xm.h.in,v 1.9 1999/11/04 11:43:44 danny Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -30,11 +30,7 @@
 #include <X11/Shell.h>
 #include <X11/Xatom.h>
 #include <Xm/XmStrDefs.h>
-#include <Xm/VirtKeys.h>
-#include <Xm/Transfer.h>
-#include <Xm/Primitive.h>
-#include <Xm/Manager.h>
-#include <Xm/Gadget.h>
+#include <Xm/VendorS.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -49,15 +45,16 @@ extern "C" {
 #endif
 
 /* Version Information */
+
 #define LESSTIF_VERSION 0
-#define LESSTIF_REVISION 88
+#define LESSTIF_REVISION 89
 
 #define LesstifVersion (LESSTIF_VERSION * 1000 + LESSTIF_REVISION)
-#define LesstifVERSION_STRING "GNU LessTif 0.88 0"
+#define LesstifVERSION_STRING "@(#)GNU/LessTif Version 1.2 Release 0.89.9"
 
-/* since we're replacing Motif 2.0... */
-#define XmVERSION 2
-#define XmREVISION 0
+/* since we're replacing Motif 1.2... */
+#define XmVERSION 1
+#define XmREVISION 2
 #define XmVersion (XmVERSION * 1000 + XmREVISION)
 #define XmVERSION_STRING LesstifVERSION_STRING
 #define XmUPDATE_LEVEL 0
@@ -89,55 +86,13 @@ extern int xmUseVersion;
 
 #define XmDEFAULT_FONT                  _XmSDEFAULT_FONT
 #define XmDEFAULT_BACKGROUND            _XmSDEFAULT_BACKGROUND
-#define XmDEFAULT_DARK_THRESHOLD        20
-#define XmDEFAULT_LIGHT_THRESHOLD       93
-#define XmDEFAULT_FOREGROUND_THRESHOLD  70
+#define XmDEFAULT_DARK_THRESHOLD        15
+#define XmDEFAULT_LIGHT_THRESHOLD       77
+#define XmDEFAULT_FOREGROUND_THRESHOLD  35
 
 extern char    _XmSDEFAULT_FONT[];
 extern char    _XmSDEFAULT_BACKGROUND[];
 
-typedef unsigned char XmDirection;
-
-#define XmDIRECTION_IGNORED 0x30
-
-#define XmRIGHT_TO_LEFT_MASK 0x01
-#define XmLEFT_TO_RIGHT_MASK 0x02
-#define XmHORIZONTAL_MASK 0x03
-#define XmTOP_TO_BOTTOM_MASK 0x04
-#define XmBOTTOM_TO_TOP_MASK 0x08
-#define XmVERTICAL_MASK 0x0c
-#define XmPRECEDENCE_HORIZ_MASK 0x40
-#define XmPRECEDENCE_VERT_MASK 0x80
-#define XmPRECEDENCE_MASK 0xc0
-
-enum {
-    XmRIGHT_TO_LEFT_TOP_TO_BOTTOM =
-        XmRIGHT_TO_LEFT_MASK | XmTOP_TO_BOTTOM_MASK | XmPRECEDENCE_HORIZ_MASK,
-    XmLEFT_TO_RIGHT_TOP_TO_BOTTOM =
-        XmLEFT_TO_RIGHT_MASK | XmTOP_TO_BOTTOM_MASK | XmPRECEDENCE_HORIZ_MASK,
-    XmRIGHT_TO_LEFT_BOTTOM_TO_TOP =
-        XmRIGHT_TO_LEFT_MASK | XmBOTTOM_TO_TOP_MASK | XmPRECEDENCE_HORIZ_MASK,
-    XmLEFT_TO_RIGHT_BOTTOM_TO_TOP =
-        XmLEFT_TO_RIGHT_MASK | XmBOTTOM_TO_TOP_MASK | XmPRECEDENCE_HORIZ_MASK,
-    XmTOP_TO_BOTTOM_RIGHT_TO_LEFT =
-        XmRIGHT_TO_LEFT_MASK | XmTOP_TO_BOTTOM_MASK | XmPRECEDENCE_VERT_MASK,
-    XmTOP_TO_BOTTOM_LEFT_TO_RIGHT =
-        XmLEFT_TO_RIGHT_MASK | XmTOP_TO_BOTTOM_MASK | XmPRECEDENCE_VERT_MASK,
-    XmBOTTOM_TO_TOP_RIGHT_TO_LEFT =
-        XmRIGHT_TO_LEFT_MASK | XmBOTTOM_TO_TOP_MASK | XmPRECEDENCE_VERT_MASK,
-    XmBOTTOM_TO_TOP_LEFT_TO_RIGHT =
-        XmLEFT_TO_RIGHT_MASK | XmBOTTOM_TO_TOP_MASK | XmPRECEDENCE_VERT_MASK,
-    XmTOP_TO_BOTTOM =
-        XmTOP_TO_BOTTOM_MASK | XmHORIZONTAL_MASK | XmPRECEDENCE_MASK,
-    XmBOTTOM_TO_TOP =
-        XmBOTTOM_TO_TOP_MASK | XmHORIZONTAL_MASK | XmPRECEDENCE_MASK,
-    XmRIGHT_TO_LEFT =
-        XmRIGHT_TO_LEFT_MASK | XmVERTICAL_MASK | XmPRECEDENCE_MASK,
-    XmLEFT_TO_RIGHT =
-        XmLEFT_TO_RIGHT_MASK | XmVERTICAL_MASK | XmPRECEDENCE_MASK,
-    XmDEFAULT_DIRECTION = 0xff
-};
-  
 /*
  * XmString stuff
  */
@@ -150,127 +105,68 @@ typedef enum {
 enum {
     XmSTRING_DIRECTION_L_TO_R, 
     XmSTRING_DIRECTION_R_TO_L,
-    XmSTRING_DIRECTION_UNSET = 3,
-    XmSTRING_DIRECTION_DEFAULT = XmDEFAULT_DIRECTION
+    XmSTRING_DIRECTION_DEFAULT = 255
 };
 
-typedef unsigned char XmStringDirection;
-typedef unsigned char *XmString;
-typedef XmString *XmStringTable;
-typedef char *XmStringCharSet;
-typedef unsigned char XmStringComponentType;
-typedef char *XmStringTag;
-
-typedef struct _XmFontListRec *XmFontListEntry, *XmFontList;
-typedef struct __XmStringContextRec *_XmStringContext;
-typedef struct __XmStringRec *_XmString;
-typedef struct _XmtStringContextRec *XmStringContext;
-typedef struct _XmFontListContextRec *XmFontContext;
-
-/* FIXTHIS: - render stuff needs to be added. */
-typedef XmFontList XmRenderTable; 
-typedef XmFontListEntry XmRendition;
-
 enum {
     XmSTRING_COMPONENT_UNKNOWN,
     XmSTRING_COMPONENT_CHARSET,
     XmSTRING_COMPONENT_TEXT,
     XmSTRING_COMPONENT_DIRECTION,
     XmSTRING_COMPONENT_SEPARATOR,
-    XmSTRING_COMPONENT_LOCALE_TEXT,
-    XmSTRING_COMPONENT_LOCALE,
-    XmSTRING_COMPONENT_WIDECHAR_TEXT,
-    XmSTRING_COMPONENT_LAYOUT_PUSH,
-    XmSTRING_COMPONENT_LAYOUT_POP,
-    XmSTRING_COMPONENT_RENDITION_BEGIN,
-    XmSTRING_COMPONENT_RENDITION_END,
-    XmSTRING_COMPONENT_TAB
-    /* 13 - 125 is said to be reserved */
+    XmSTRING_COMPONENT_LOCALE_TEXT
+    /* 6 - 125 is said to be reserved */
 };
 
-#define XmSTRING_COMPONENT_FONTLIST_ELEMENT_TAG XmSTRING_COMPONENT_CHARSET
-
-#define XmSTRING_COMPONENT_TAG          XmSTRING_COMPONENT_CHARSET
-
 #define XmSTRING_COMPONENT_END          ((XmStringComponentType) 126)
 /* anybody know what 127 is? */
 #define XmSTRING_COMPONENT_USER_BEGIN   ((XmStringComponentType) 128)
 /* 128-255 are user tags */
 #define XmSTRING_COMPONENT_USER_END     ((XmStringComponentType) 255)
 
-typedef enum {
-    XmCHARSET_TEXT,
-    XmMULTIBYTE_TEXT,
-    XmWIDECHAR_TEXT,
-    XmNO_TEXT
-} XmTextType;
+typedef unsigned char XmStringDirection;
+typedef unsigned char *XmString;
+typedef XmString *XmStringTable;
+typedef char *XmStringCharSet;
+typedef unsigned char XmStringComponentType;
 
-typedef enum {
-    XmOUTPUT_ALL,
-    XmOUTPUT_BETWEEN,
-    XmOUTPUT_BEGINNING,
-    XmOUTPUT_END,
-    XmOUTPUT_BOTH
-} XmParseModel;
+typedef struct _XmFontListRec *XmFontListEntry, *XmFontList;
+typedef struct __XmStringContextRec *_XmStringContext;
+typedef struct __XmStringRec *_XmString;
+typedef struct _XmtStringContextRec *XmStringContext;
+typedef struct _XmFontListContextRec *XmFontContext;
 
-typedef unsigned char XmIncludeStatus;
+/*
+ * make sure the big three are always defined
+ */
 
-enum {
-    XmINSERT,
-    XmTERMINATE,
-    XmINVOKE
-};
+extern WidgetClass xmPrimitiveWidgetClass;
 
-typedef enum {
-    XmSTYLE_STRING = XStringStyle,
-    XmSTYLE_COMPOUND = XCompoundTextStyle,
-    XmSTYLE_TEXT = XTextStyle,
-    XmSTYLE_STANDARD_ICC_TEXT = XStdICCTextStyle,
-    XmSTYLE_LOCALE = 32,
-    XmSTYLE_COMPOUND_STRING
-} XmICCEncodingStyle;
+typedef struct _XmPrimitiveClassRec *XmPrimitiveWidgetClass;
+typedef struct _XmPrimitiveRec      *XmPrimitiveWidget;
 
-/* tab list stuff */
-typedef enum {
-    XmABSOLUTE,
-    XmRELATIVE
-} XmOffsetModel;
+extern WidgetClass xmGadgetClass;
 
-typedef struct __XmTabRec *XmTab;
-typedef struct __XmTabListRec  *XmTabList;
+typedef struct _XmGadgetClassRec *XmGadgetClass;
+typedef struct _XmGadgetRec      *XmGadget;
 
-/* render table stuff */
+extern WidgetClass xmManagerWidgetClass;
 
-typedef enum {
-    XmSKIP,
-    XmREPLACE,
-    XmMERGE_OLD,
-    XmMERGE_NEW,
-    XmDUPLICATE   /* For XmFontListAdd and XmFontListAppendEntry. */
-} XmMergeMode;
+typedef struct _XmManagerClassRec *XmManagerWidgetClass;
+typedef struct _XmManagerRec      *XmManagerWidget;
 
-#define XmAS_IS 255
-#define XmFORCE_COLOR 1
+#ifndef XmIsPrimitive
+#define XmIsPrimitive(w)        XtIsSubclass(w, xmPrimitiveWidgetClass)
+#endif
 
-#define XmUNSPECIFIED_PIXEL ((Pixel) (~0))
-#define XmDEFAULT_SELECT_COLOR XmUNSPECIFIED_PIXEL
-#define XmREVERSED_GROUND_COLORS (XmDEFAULT_SELECT_COLOR - 1)
-#define XmHIGHLIGHT_COLOR (XmREVERSED_GROUND_COLORS - 1)
+#ifndef XmIsGadget
+#define XmIsGadget(w)           XtIsSubclass(w, xmGadgetClass)
+#endif
 
-enum {
-    XmUNSPECIFIED_LOAD_MODEL,
-    XmLOAD_DEFERRED,
-    XmLOAD_IMMEDIATE
-};
+#ifndef XmIsManager
+#define XmIsManager(w)          XtIsSubclass(w, xmManagerWidgetClass)
+#endif
 
-/* size policy stuff */
-
-enum {
-    XmCHANGE_ALL,
-    XmCHANGE_NONE,
-    XmCHANGE_WIDTH,
-    XmCHANGE_HEIGHT
-};
 
 /* unitType stuff */
 
@@ -315,16 +211,6 @@ enum {
     XmBELL = 1
 };
 
-/* Input Manager types */
-enum {
-    XmPER_SHELL,
-    XmPER_WIDGET,
-    XmINHERIT_POLICY = 255
-};
-
-/* Note: The define in XmI.h was changed to XmIMInputPolicy. */
-typedef unsigned char XmInputPolicy;
-
 /* various widgets' orientation, menu definitions */
 
 enum {
@@ -378,17 +264,6 @@ enum {
 	XmFIRST_POSITION
 };
 
-/* XmComboBox types */
-enum {
-   XmCOMBO_BOX = 0,
-   XmDROP_DOWN_LIST,
-   XmDROP_DOWN_COMBO_BOX
-};
-
-enum {
-   XmQUICK_NAVIGATE = 1
-};
-
 /* Label and Frame alignments */
 
 enum {
@@ -422,15 +297,9 @@ enum {
 #else
     XmN_OF_MANY = 1,
 #endif
-    XmONE_OF_MANY,
-    XmONE_OF_MANY_ROUND
+    XmONE_OF_MANY
 };
 
-enum { XmUNSET, XmSET, XmINDETERMINATE };
-enum { XmTOGGLE_BOOLEAN, XmTOGGLE_INDETERMINATE };
-
-typedef unsigned char XmToggleButtonState;
-
 /* Form attachments */
 
 enum {
@@ -454,77 +323,54 @@ enum {
 /* callback reasons */
 
 enum {
-    XmCR_NONE,				/* 0 */
-    XmCR_HELP,				/* 1 */
-    XmCR_VALUE_CHANGED,			/* 2 */
-    XmCR_INCREMENT,			/* 3 */
-    XmCR_DECREMENT,			/* 4 */
-    XmCR_PAGE_INCREMENT,		/* 5 */
-    XmCR_PAGE_DECREMENT,		/* 6 */
-    XmCR_TO_TOP,			/* 7 */
-    XmCR_TO_BOTTOM,			/* 8 */
-    XmCR_DRAG,				/* 9 */
-    XmCR_ACTIVATE,			/* 10 */
-    XmCR_ARM,				/* 11 */
-    XmCR_DISARM,			/* 12 */
-    XmCR_DUMMY13,			/* 13 */
-    XmCR_DUMMY14,			/* 14 */
-    XmCR_DUMMY15,			/* 15 */
-    XmCR_MAP,				/* 16 */
-    XmCR_UNMAP,				/* 17 */
-    XmCR_FOCUS,				/* 18 */
-    XmCR_LOSING_FOCUS,			/* 19 */
-    XmCR_MODIFYING_TEXT_VALUE,		/* 20 */
-    XmCR_MOVING_INSERT_CURSOR,		/* 21 */
-    XmCR_EXECUTE,			/* 22 */
-    XmCR_SINGLE_SELECT,			/* 23 */
-    XmCR_MULTIPLE_SELECT,		/* 24 */
-    XmCR_EXTENDED_SELECT,		/* 25 */
-    XmCR_BROWSE_SELECT,			/* 26 */
-    XmCR_DEFAULT_ACTION,		/* 27 */
-    XmCR_CLIPBOARD_DATA_REQUEST,	/* 28 */
-    XmCR_CLIPBOARD_DATA_DELETE,		/* 29 */
-    XmCR_CASCADING,			/* 30 */
-    XmCR_OK,				/* 31 */
-    XmCR_CANCEL,			/* 32 */
-    XmCR_DUMMY33,			/* 33 */
-    XmCR_APPLY,				/* 34 */
-    XmCR_NO_MATCH,			/* 35 */
-    XmCR_COMMAND_ENTERED,		/* 36 */
-    XmCR_COMMAND_CHANGED,		/* 37 */
-    XmCR_EXPOSE,			/* 38 */
-    XmCR_RESIZE,			/* 39 */
-    XmCR_INPUT,				/* 40 */
-    XmCR_GAIN_PRIMARY,			/* 41 */
-    XmCR_LOSE_PRIMARY,			/* 42 */
-    XmCR_CREATE,			/* 43 */
-    XmCR_TEAR_OFF_ACTIVATE,		/* 44 */
-    XmCR_TEAR_OFF_DEACTIVATE,		/* 45 */
-    XmCR_OBSCURED_TRAVERSAL,		/* 46 */
-    XmCR_FOCUS_MOVED,			/* 47 */
-    XmCR_DUMMY48,			/* 48 */
-    XmCR_DUMMY49,			/* 49 */
-    XmCR_DUMMY50,			/* 50 */
-    XmCR_DUMMY51,			/* 51 */
-    XmCR_DUMMY52,			/* 52 */
-    XmCR_DUMMY53,			/* 53 */
-    XmCR_REPOST,			/* 54 */
-    XmCR_COLLAPSED,			/* 55 */
-    XmCR_EXPANDED,			/* 56 */
-    XmCR_SELECT,			/* 57 */
-    XmCR_DRAG_START,			/* 58 */
-    XmCR_NO_FONT,			/* 59 */
-    XmCR_NO_RENDITION,			/* 60 */
-    XmCR_POST,				/* 61 */
-    XmCR_SPIN_NEXT,			/* 62 */
-    XmCR_SPIN_PRIOR,			/* 63 */
-    XmCR_SPIN_FIRST,			/* 64 */
-    XmCR_SPIN_LAST,			/* 65 */
-    XmCR_PAGE_SCROLLER_INCREMENT,	/* 66 */
-    XmCR_PAGE_SCROLLER_DECREMENT,	/* 67 */
-    XmCR_MAJOR_TAB,			/* 68 */
-    XmCR_MINOR_TAB,			/* 69 */
-    XmCR_PROTOCOLS = 6666		/* Note: this was 47 in Motif 1.2x */
+    XmCR_NONE,			/* 0 */
+    XmCR_HELP,			/* 1 */
+    XmCR_VALUE_CHANGED,		/* 2 */
+    XmCR_INCREMENT,		/* 3 */
+    XmCR_DECREMENT,		/* 4 */
+    XmCR_PAGE_INCREMENT,	/* 5 */
+    XmCR_PAGE_DECREMENT,	/* 6 */
+    XmCR_TO_TOP,		/* 7 */
+    XmCR_TO_BOTTOM,		/* 8 */
+    XmCR_DRAG,			/* 9 */
+    XmCR_ACTIVATE,		/* 10 */
+    XmCR_ARM,			/* 11 */
+    XmCR_DISARM,		/* 12 */
+    XmCR_DUMMY13,		/* 13 */
+    XmCR_DUMMY14,		/* 14 */
+    XmCR_DUMMY15,		/* 15 */
+    XmCR_MAP,			/* 16 */
+    XmCR_UNMAP,			/* 17 */
+    XmCR_FOCUS,			/* 18 */
+    XmCR_LOSING_FOCUS,		/* 19 */
+    XmCR_MODIFYING_TEXT_VALUE,	/* 20 */
+    XmCR_MOVING_INSERT_CURSOR,	/* 21 */
+    XmCR_EXECUTE,		/* 22 */
+    XmCR_SINGLE_SELECT,		/* 23 */
+    XmCR_MULTIPLE_SELECT,	/* 24 */
+    XmCR_EXTENDED_SELECT,	/* 25 */
+    XmCR_BROWSE_SELECT,		/* 26 */
+    XmCR_DEFAULT_ACTION,	/* 27 */
+    XmCR_CLIPBOARD_DATA_REQUEST,/* 28 */
+    XmCR_CLIPBOARD_DATA_DELETE,	/* 29 */
+    XmCR_CASCADING,		/* 30 */
+    XmCR_OK,			/* 31 */
+    XmCR_CANCEL,		/* 32 */
+    XmCR_DUMMY33,		/* 33 */
+    XmCR_APPLY,			/* 34 */
+    XmCR_NO_MATCH,		/* 35 */
+    XmCR_COMMAND_ENTERED,	/* 36 */
+    XmCR_COMMAND_CHANGED,	/* 37 */
+    XmCR_EXPOSE,		/* 38 */
+    XmCR_RESIZE,		/* 39 */
+    XmCR_INPUT,			/* 40 */
+    XmCR_GAIN_PRIMARY,		/* 41 */
+    XmCR_LOSE_PRIMARY,		/* 42 */
+    XmCR_CREATE,		/* 43 */
+    XmCR_TEAR_OFF_ACTIVATE,	/* 44 */
+    XmCR_TEAR_OFF_DEACTIVATE,	/* 45 */
+    XmCR_OBSCURED_TRAVERSAL,	/* 46 */
+    XmCR_PROTOCOLS		/* 47 */
 };
 
 /*
@@ -542,13 +388,6 @@ typedef struct {
     int click_count;
 } XmArrowButtonCallbackStruct;
 
-typedef struct {
-    int reason;
-    XEvent *event;
-    XmString item_or_text;
-    int item_position;
-} XmComboBoxCallbackStruct;
-
 typedef struct {
     int reason;
     XEvent *event;
@@ -556,48 +395,18 @@ typedef struct {
     int length;
 } XmCommandCallbackStruct;
 
-typedef struct {
-    int reason;
-    XEvent *event;
-    Widget item;
-    unsigned char new_outline_state;
-} XmContainerOutlineCallbackStruct;
-
-typedef struct {
-    int reason;
-    XEvent *event;
-    WidgetList selected_items;
-    int selected_item_count;
-    unsigned char auto_selection_type;
-} XmContainerSelectCallbackStruct;
-
-typedef struct {
-    int reason;
-    XEvent *event;
-    XmRendition rendition;
-    char *font_name;
-    XmRenderTable render_table;
-    XmStringTag tag;
-} XmDisplayCallbackStruct;
-
-typedef struct _XmDragStartCallbackStruct {
-    int reason;
-    XEvent *event;
-    Widget widget;
-    Boolean doit;
-} XmDragStartCallbackStruct, *XmDragStartCallback;
-
 typedef struct {
     int reason;
     XEvent *event;
     Window window;
 } XmDrawingAreaCallbackStruct;
 
-typedef struct {
-    int reason;
-    XEvent *event;
-    Window window;
-    int click_count;
+typedef struct
+{
+    int     reason;
+    XEvent  *event;
+    Window  window;
+    int     click_count;
 } XmDrawnButtonCallbackStruct;
 
 typedef struct {
@@ -625,23 +434,6 @@ typedef struct {
     int selection_type;           /* type of most recent selection */
 } XmListCallbackStruct;
 
-typedef struct {
-    int reason;
-    XEvent *event;
-    int page_number;
-    Widget page_widget;
-    int prev_page_number;
-    Widget prev_page_widget;
-} XmNotebookCallbackStruct;
-
-typedef struct {
-    int reason;
-    XEvent *event;
-    Widget menuToPost;
-    Boolean postIt;
-    Widget target;
-} XmPopupHandlerCallbackStruct;
-
 typedef struct {
     int reason;                   /* reason callback was called */
     XEvent *event;
@@ -677,16 +469,6 @@ typedef struct {
     int length;
 } XmSelectionBoxCallbackStruct;
 
-typedef struct {
-    int reason;
-    XEvent *event;
-    Widget widget;
-    Boolean doit;
-    int position;
-    XmString value;
-    Boolean crossed_boundary;
-} XmSpinBoxCallbackStruct;
-
 typedef struct {
     int reason;                   /* reason callback was called */
     XEvent *event;
@@ -768,158 +550,6 @@ enum {
     XmDYNAMIC
 };
 
-enum {
-    XmNORMAL_MODE,
-    XmADD_MODE
-};
-
-/* container stuff */
-
-/* for XmRAutomaticSelection */
-enum {
-    XmNO_AUTO_SELECT,
-    XmAUTO_SELECT
-};
-
-/* for XmRLineStyle */
-enum { 
- /* XmNO_LINE */
-    XmSINGLE = 1
-};
-
-/* for XmREntryViewType */
-enum {
- /* XmLARGE_ICON */
- /* XmSMALL_ICON */
-    XmANY_ICON = 2
-};
-
-/* for XmRSpatialIncludeModel */
-enum {
-    XmAPPEND,
-    XmCLOSEST,
-    XmFIRST_FIT
-};
-
-/* for XmRLayoutType */
-enum {
-    XmOUTLINE,
-    XmSPATIAL,
-    XmDETAIL
-};
-
-/* for XmNoutlineButtonPolicy */
-enum {
-    XmOUTLINE_BUTTON_PRESENT,
-    XmOUTLINE_BUTTON_ABSENT
-};
-
-/* for XmRSpatialPlaceStyle */
-enum {
- /* XmNONE */
-    XmGRID = 1,
-    XmCELLS
-};
-
-/* for XmRPrimaryOwnership */
-enum {
-    XmOWN_NEVER,
-    XmOWN_ALWAYS,
-    XmOWN_MULTIPLE,
-    XmOWN_POSSIBLE_MULTIPLE
-};
-
-/* for XmRSpatialResizeModel */
-enum {
-    XmGROW_MINOR,
-    XmGROW_MAJOR,
-    XmGROW_BALANCED
-};
-
-/* for XmRSelectionTechnique */
-enum {
-    XmMARQUEE,
-    XmMARQUEE_EXTEND_START,
-    XmMARQUEE_EXTEND_BOTH,
-    XmTOUCH_ONLY,
-    XmTOUCH_OVER
-};
-
-/* for XmRSpatialSnapModel */
-enum {
- /* XmNONE */
-    XmSNAP_TO_GRID = 1,
-    XmCENTER
-};
-
-/* for XmROutlineState */
-enum {
-    XmCOLLAPSED,
-    XmEXPANDED
-};
-
-/* icon gadget stuff */
-
-/* for XmRViewType */
-enum {
-    XmLARGE_ICON,
-    XmSMALL_ICON
-};
-
-/* for XmRVisualEmphasis */
-enum {
-    XmSELECTED,
-    XmNOT_SELECTED
-};
-
-/* notebook stuff */
-
-#define XmUNSPECIFIED_PAGE_NUMBER       (-32768)
-
-/* for XmRBindingType */
-enum {  
- /* XmNONE */
- /* XmPIXMAP */
-    XmSOLID = 2,
-    XmSPIRAL,
-    XmPIXMAP_OVERLAP_ONLY
-};
-
-/* for XmRNBChildType */
-enum {
- /* XmNONE */
-    XmPAGE = 1,
-    XmMAJOR_TAB,
-    XmMINOR_TAB,
-    XmSTATUS_AREA,
-    XmPAGE_SCROLLER
-};
-
-/* spin box stuff */
-
-/* for XmNarrowLayout */
-enum {
-    XmARROWS_END,
-    XmARROWS_BEGINNING,
-    XmARROWS_SPLIT,
-    XmARROWS_FLAT_END,
-    XmARROWS_FLAT_BEGINNING
-};
-
-/* for XmNarrowSensitivity or XmNdefaultArrowSensitivity */
-enum {
-    XmARROWS_INSENSITIVE,
-    XmARROWS_INCREMENT_SENSITIVE,
-    XmARROWS_DECREMENT_SENSITIVE,
-    XmARROWS_SENSITIVE,
-    XmARROWS_DEFAULT_SENSITIVITY
-};
-
-/* for XmNspinBoxChildType */
-enum {
-    XmNUMERIC = 3
-};
-
 /* scrolled window policy stuff */
 
 enum {
@@ -990,8 +620,7 @@ typedef enum {
     XmSELECT_WORD,
     XmSELECT_LINE,
     XmSELECT_ALL,
-    XmSELECT_PARAGRAPH,
-    XmSELECT_OUT_LINE
+    XmSELECT_PARAGRAPH
 } XmTextScanType;
 
 /* highlight mode for text and textfield widgets */
@@ -1175,9 +804,6 @@ typedef struct _XmSecondaryResourceDataRec {
 Cardinal XmGetSecondaryResourceData(WidgetClass wc,
 				    XmSecondaryResourceData **resData);
 
-/************************ GadgetUtils.c ***************************/
-XmGadget XmObjectAtPoint(Widget cw, int x, int y);
-
 /************************ ImageCache.c ***************************/
 Pixmap XmGetPixmap(Screen *screen, char *image_name, Pixel foreground, Pixel background);
 Pixmap XmGetPixmapByDepth(Screen *screen, char *image_name, Pixel foreground, Pixel background, int depth);
@@ -1201,64 +827,9 @@ Boolean XmWidgetGetBaselines(Widget wid, Dimension **baselines,
 			     int *line_count);
 Boolean XmWidgetGetDisplayRect(Widget wid, XRectangle *displayrect);
 
-/************************** RenderTable.c ****************************/
-
-XmRenderTable XmRenderTableAddRenditions(XmRenderTable        oldtable,
-					 XmRendition    *renditions,
-					 Cardinal       rendition_count,
-					 XmMergeMode    merge_mode);
-
-XmRenderTable XmRenderTableCopy(XmRenderTable table,
-				XmStringTag     *tags,
-				int             tag_count);
-
-XmRenderTable XmRenderTableCvtFromProp(Widget         widget,
-				       char             *property,
-				       unsigned int     length);
-
-unsigned int XmRenderTableCvtToProp(Widget            widget,
-				    XmRenderTable       table,
-				    char                **prop_return);
-
-void XmRenderTableFree(XmRenderTable table);
-
-XmRendition XmRenderTableGetRendition(XmRenderTable   table,
-				      XmStringTag       tag);
-
-XmRendition *XmRenderTableGetRenditions(XmRenderTable table,
-					XmStringTag     *tags,
-					Cardinal        tag_count);
-
-int XmRenderTableGetTags(XmRenderTable        table,
-			 XmStringTag    **tag_list);
-
-XmRenderTable XmRenderTableRemoveRenditions(XmRenderTable     oldtable,
-					    XmStringTag *tags,
-					    int         tag_count);
-
-Boolean XmeRenderTableGetDefaultFont(XmRenderTable    renderTable,
-				     XFontStruct        **fontStruct);
-
-XmString XmStringGenerate(XtPointer   text,
-			  XmStringTag   tag,
-			  XmTextType    type,
-			  XmStringTag   rendition);
-  
-XmRendition XmRenditionCreate(Widget widget,
-			      XmStringTag tag,
-			      ArgList arglist,
-			      Cardinal argcount);
-  
-void XmRenditionFree(XmRendition rendition);
-
-void XmRenditionUpdate(XmRendition rendition, 
-		       ArgList arglist, 
-		       Cardinal argcount);
-
-
 /************************ ResConvert.c ****************************/
 
-void XmRegisterConverters();
+void XmRegisterConverters(void);
 void XmCvtStringToUnitType(XrmValuePtr args, Cardinal *num_args, XrmValue *from_val, XrmValue *to_val);
 char *XmRegisterSegmentEncoding(char *fontlist_tag, char *ct_encoding);
 char *XmMapSegmentEncoding(char *fontlist_tag);
@@ -1335,7 +906,7 @@ typedef void (*XmColorProc)(XColor *bg_color, XColor *fg_color,
 
 
 extern XmColorProc XmSetColorCalculation(XmColorProc proc);
-extern XmColorProc XmGetColorCalculation();
+extern XmColorProc XmGetColorCalculation(void);
 extern void XmGetColors(Screen *screen, Colormap color_map,
 			Pixel background, Pixel *foreground_ret,
 			Pixel *top_shadow_ret, Pixel *bottom_shadow_ret,
@@ -1348,7 +919,6 @@ Dimension XmStringBaseline(XmFontList fontlist, XmString string);
 Boolean XmStringByteCompare(XmString s1, XmString s2);
 Boolean XmStringCompare(XmString s1, XmString s2);
 XmString XmStringConcat(XmString s1, XmString s2);
-XmString XmStringConcatAndFree(XmString s1, XmString s2);
 XmString XmStringCreate(char *text, char *tag);
 XmString XmStringCreateLtoR(char *text, char *tag);
 XmString XmStringLtoRCreate(char *text, char *tag);
@@ -1419,7 +989,7 @@ XmStringComponentType XmStringPeekNextComponent(XmStringContext context);
 XmString XmStringSegmentCreate(char *text, char *tag, 
 			       XmStringDirection direction,
 			       Boolean separator);
-XmString XmStringSeparatorCreate();
+XmString XmStringSeparatorCreate(void);
 
 Dimension XmStringWidth(XmFontList fontList, XmString string);
 
@@ -1482,81 +1052,7 @@ int XmImMbLookupString(Widget w, XKeyPressedEvent *event, char *buf,
 extern void XmImVaSetFocusValues(Widget w, ...);
 extern void XmImVaSetValues(Widget w, ...);
 
-/**************************** Direction.c *********************************/
-
-Boolean XmDirectionMatch(XmDirection dir1, XmDirection dir2);
-Boolean XmDirectionMatchPartial(XmDirection dir1, XmDirection dir2, XmDirection dir_mask);
-XmStringDirection XmDirectionToStringDirection(XmDirection dir);
-XmDirection XmStringDirectionToDirection(XmStringDirection sdir);
-
-#ifdef __cplusplus
-}
-#endif
-
-#include <Xm/VendorS.h>
-/*
-FIXTHIS: Need to add header XmIm.h.
-#if 0
-#include <Xm/XmIm.h>
-#endif
-*/
-
-/* REMARK: Motif 2.0 does not enclose this with an extern C which is a bug. */
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-/* The following is for backwards compability (bc) */
-#define XmINDICATOR_3D_BOX 0x01
-#define XmINDICATOR_FLAT_BOX 0x02
-#define XmINDICATOR_CHECK_GLYPH 0x10
-#define XmINDICATOR_CROSS_GLYPH 0x20
-
-enum {
-    XmINDICATOR_NONE = 0,
-    XmINDICATOR_FILL = XmINDICATOR_3D_BOX,
-    XmINDICATOR_CHECK = XmINDICATOR_CHECK_GLYPH,
-    XmINDICATOR_CHECK_BOX = XmINDICATOR_CHECK_GLYPH + XmINDICATOR_3D_BOX,
-    XmINDICATOR_CROSS = XmINDICATOR_CROSS_GLYPH,
-    XmINDICATOR_CROSS_BOX = XmINDICATOR_CROSS_GLYPH + XmINDICATOR_3D_BOX
-};
-
-/* A slider can either be a slider or a thermometer */
-enum { XmSLIDER, XmTHERMOMETER };
-
-#define XmTextSetTopPosition    XmTextSetTopCharacter 
-
-/* As requested by Rick Niles <niles@axp745.gsfc.nasa.gov> */
-enum {
-	XmPOPUP_DISABLED = 0,
-	XmPOPUP_KEYBOARD,
-	XmPOPUP_AUTOMATIC,
-	XmPOPUP_AUTOMATIC_RECURSIVE
-};
-
-/* Slider */
-enum {
-	XmBACKGROUND_COLOR,
-	XmFOREGROUND_COLOR,
-	XmTROUGH_COLOR,
-	XmSHADOWED_BACKGROUND
-};
-
-enum {
-	XmNEAR_SLIDER = 1,
-        XmNEAR_BORDER
-};
-
-enum {
-	/* XmNONE */
-	XmETCHED_LINE = 1,
-	XmTHUMB_MARK,
-	XmROUND_MARK
-};
-/* XmString */
-extern XmString XmStringGenerate(XtPointer   text, XmStringTag tag,
-	XmTextType  type, XmStringTag rendition);
-
+#define	XmTextSetTopPosition	XmTextSetTopCharacter
 #ifdef __cplusplus
 }
 #endif
